@@ -286,7 +286,7 @@ void TestMovableType::errorPost(KBlog::Blog::ErrorType type, const QString &errS
         break;
     };
     qDebug() << "error: " << errStr;
-    if (post != 0) {
+    if (post != nullptr) {
         dumpPost(post);
     }
     qDebug() << "#############################\n";
